[Libreoffice-commits] core.git: sw/qa

Stephan Bergmann (via logerrit) logerrit at kemper.freedesktop.org
Fri Sep 20 11:50:29 UTC 2019


 sw/qa/extras/uiwriter/uiwriter2.cxx |    8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

New commits:
commit ed7df853b62f9ed429ce277bb4a5f72ba8f3f520
Author:     Stephan Bergmann <sbergman at redhat.com>
AuthorDate: Tue Sep 17 15:08:29 2019 +0200
Commit:     Stephan Bergmann <sbergman at redhat.com>
CommitDate: Fri Sep 20 13:49:20 2019 +0200

    Fix CppunitTest_sw_uiwriter for my Windows build
    
    ...which reports 271 instead of 276 here, for whatever reason
    
    Change-Id: I897fcfdc83055e4c2aacd024792266afd0754ab5
    Reviewed-on: https://gerrit.libreoffice.org/79065
    Tested-by: Jenkins
    Reviewed-by: Stephan Bergmann <sbergman at redhat.com>

diff --git a/sw/qa/extras/uiwriter/uiwriter2.cxx b/sw/qa/extras/uiwriter/uiwriter2.cxx
index b2567809d968..fda0561288c1 100644
--- a/sw/qa/extras/uiwriter/uiwriter2.cxx
+++ b/sw/qa/extras/uiwriter/uiwriter2.cxx
@@ -2248,9 +2248,11 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest2, testTdf105330)
     sw::UndoManager& rUndoManager = pDoc->GetUndoManager();
     rUndoManager.Undo();
 
-    //  Without the accompanying fix in place, height was only 1 twips (practically invisible).
-    CPPUNIT_ASSERT_EQUAL(static_cast<long>(276),
-                         pWrtShell->GetVisibleCursor()->GetTextCursor().GetSize().getHeight());
+    //  Without the accompanying fix in place, height was only 1 twips (practically invisible), with
+    // the fix in place it is seen to be either 271 or 276 for different builds:
+    CPPUNIT_ASSERT_GREATEREQUAL(
+        static_cast<long>(271),
+        pWrtShell->GetVisibleCursor()->GetTextCursor().GetSize().getHeight());
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */


More information about the Libreoffice-commits mailing list